@@ -10,22 +10,23 @@
 #' @keywords internal
 #' @param folder The file path to the folder that needs to be cleaned up (the root directory of the data package)
 #' @param orig The list of files that were present in the folder before unzipping and stacking
-#' @return Any existing directory except for stackedFiles will be removed. Nothing is returned.
+#' @return Only the folders created during unzip will be deleted. All custom folders/files and the stackedFiles output folder will be retained.
 
 #' @references
 #' License: GNU AFFERO GENERAL PUBLIC LICENSE Version 3, 19 November 2007
 
 # Changelog and author contributions / copyrights
 #   Christine Laney (2018-01-10)
+#   Nathan Mietkiewicz (2020-02-12)
 ##############################################################################################
 cleanUp <- function(folder, orig) {
-  dirs <- list.dirs(folder, recursive = FALSE)
-  dirsNotStacked <- dirs[-grep(pattern = "stackedFiles", x = dirs)]
-  dirsNotStacked <- dirsNotStacked[!dirsNotStacked %in% orig]
-  if(length(dirsNotStacked) > 0) {unlink(dirsNotStacked, recursive = TRUE)}
-  fil <- list.files(folder, recursive = FALSE)
-  csvfil <- fil[grep("csv", fil)]
-  csvfil <- csvfil[!csvfil %in% orig]
-  if(length(csvfil) > 0) {unlink(paste(folder, csvfil, sep="/"), recursive = FALSE)}
+  
+  zipPattern <- paste(orig, collapse = '|')
+  currentFileList <- list.files(folder, full.names = TRUE, pattern = zipPattern)
+  
+  if(length(currentFileList) > 0) {
+    unlink(currentFileList, recursive = TRUE)
+  }
+  
   writeLines("All unzipped monthly data folders have been removed.")
 }
